@@ -1,40 +1,17 @@
 
 /*
-   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
-   All rights reserved.
+   SPDX-FileCopyrightText: 2003-2007 Clarence Dang <dang@kde.org>
 
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   1. Redistributions of source code must retain the above copyright
-      notice, this list of conditions and the following disclaimer.
-   2. Redistributions in binary form must reproduce the above copyright
-      notice, this list of conditions and the following disclaimer in the
-      documentation and/or other materials provided with the distribution.
-
-   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+   SPDX-License-Identifier: BSD-2-Clause
 */
 
-
 #ifndef kpAbstractSelectionTool_H
 #define kpAbstractSelectionTool_H
 
-
 #include "tools/kpTool.h"
 
 #include <QVariant>
 
-
 class QKeyEvent;
 class QPoint;
 class QRect;
@@ -44,7 +21,6 @@ class kpAbstractSelectionContentCommand;
 class kpCommand;
 class kpToolSelectionEnvironment;
 
-
 // The abstract base for all selection tools.
 //
 //
@@ -110,56 +86,59 @@ class kpToolSelectionEnvironment;
 //
 class kpAbstractSelectionTool : public kpTool
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-    kpAbstractSelectionTool (const QString &text, const QString &description,
-        int key,
-        kpToolSelectionEnvironment *environ, QObject *parent,
-        const QString &name);
-
-    ~kpAbstractSelectionTool () override;
+    kpAbstractSelectionTool(const QString &text,
+                            const QString &description,
+                            int key,
+                            kpToolSelectionEnvironment *environ,
+                            QObject *parent,
+                            const QString &name);
 
+    ~kpAbstractSelectionTool() override;
 
     // Inform kpTool to call draw() when CTRL, SHIFT and friends are
     // pressed.  CTRL is used for copying, instead of moving, the
     // selection.  SHIFT is used for sweeping.
-    bool careAboutModifierState () const override { return true; }
+    bool careAboutModifierState() const override
+    {
+        return true;
+    }
 
-
-//
-// Drawing - Subclass Accessors
-//
+    //
+    // Drawing - Subclass Accessors
+    //
 
 protected:
     friend struct kpAbstractSelectionToolPrivate;
-    enum DrawType
-    {
-        None, Create, Move, SelectText, ResizeScale
+    enum DrawType {
+        None,
+        Create,
+        Move,
+        SelectText,
+        ResizeScale
     };
 
-
     // The return value is not "None" during a drawing operation.
     //
     // The returned value is set by beginDraw(), after being determined
     // by calculateDrawType().  It is cleared in cancelShape() and endDraw().
-    DrawType drawType () const;
+    DrawType drawType() const;
 
-    bool hadSelectionBeforeDraw () const;
+    bool hadSelectionBeforeDraw() const;
 
-
-//
-// Drawing
-//
+    //
+    // Drawing
+    //
 
 protected:
     // (overrides non-virtual method in kpTool)
-    kpToolSelectionEnvironment *environ () const;
+    kpToolSelectionEnvironment *environ() const;
 
     // Returns whether a CTRL or SHIFT key is currently pressed.
     // Convenience method.
-    bool controlOrShiftPressed () const;
-
+    bool controlOrShiftPressed() const;
 
 protected:
     // Deselects the current selection:
@@ -172,29 +151,28 @@ protected:
     //   1. There is a current selection.
     //   2. You have not called giveContentIfNeeded() nor
     //      addNeedingContentCommand() on the current selection.
-    void pushOntoDocument ();
+    void pushOntoDocument();
 
-
-//
-// The command lifecycle is as follows:
-//
-// 1. Ensure that the document has a selection, with or without content.
-//
-// 2. Call giveContentIfNeeded().
-//
-// 3. Create the command.
-//
-// 4. Process user input, mutate the selection directly and update the
-//    command with the user's input.
-//
-// 5. When the drawing operation is complete, call addNeedingContentCommand()
-//    with the command created in Step 3.
-//
+    //
+    // The command lifecycle is as follows:
+    //
+    // 1. Ensure that the document has a selection, with or without content.
+    //
+    // 2. Call giveContentIfNeeded().
+    //
+    // 3. Create the command.
+    //
+    // 4. Process user input, mutate the selection directly and update the
+    //    command with the user's input.
+    //
+    // 5. When the drawing operation is complete, call addNeedingContentCommand()
+    //    with the command created in Step 3.
+    //
 protected:
     // Returns a new instance of the give-the-selection-content command
     // that matches the current selection type.  The command should not be
     // executed by this method.
-    virtual kpAbstractSelectionContentCommand *newGiveContentCommand () const = 0;
+    virtual kpAbstractSelectionContentCommand *newGiveContentCommand() const = 0;
 
     // Before changing a selection (e.g. moving or resizing), you must
     // ensure that it has content.  Call this method to ensure that.
@@ -204,11 +182,11 @@ protected:
     // nothing.
     //
     // ASSUMPTION: There is a selection.
-    void giveContentIfNeeded ();
+    void giveContentIfNeeded();
 
     // The name that should be given to command that is constructed in
     // response to a drag that creates a new selection.
-    virtual QString nameOfCreateCommand () const = 0;
+    virtual QString nameOfCreateCommand() const = 0;
 
     // Add a command to the command history.
     // The command is not executed.
@@ -225,8 +203,7 @@ protected:
     //
     // ASSUMPTION: giveContentIfNeeded() must have been called before
     //             creating <cmd>.
-    void addNeedingContentCommand (kpCommand *cmd);
-
+    void addNeedingContentCommand(kpCommand *cmd);
 
 protected:
     // Sets the selection border mode when no drawing operation is active.
@@ -234,28 +211,26 @@ protected:
     // Subclasses may wish to reimplement but should still call the base
     // implementation.  Reimplementations should wrap the whole
     // reimplementation in a kpViewManager::setQueueUpdates() block.
-    virtual void setSelectionBorderForHaventBegunDraw ();
+    virtual void setSelectionBorderForHaventBegunDraw();
+
 private:
     // Returns the statusbar message from when no draw operation is in
     // progress.  Calls operation() with "HaventBegunDrawUserMessage".
     //
     // (not const due to purely syntactic issue: it calls the non-const
     //  operation(); it really acts like a const method though)
-    QString haventBegunDrawUserMessage ();
-
+    QString haventBegunDrawUserMessage();
 
 public:
-    void begin () override;
-    void end () override;
-
+    void begin() override;
+    void end() override;
 
 public:
-    void reselect () override;
+    void reselect() override;
 
-
-//
-// Drawing - Beginning a Drag
-//
+    //
+    // Drawing - Beginning a Drag
+    //
 
 protected:
     // Called by calculateDrawType() to determine what type of draw type
@@ -266,7 +241,7 @@ protected:
     //
     // You are free to reimplement this and may choose to call this base
     // implementation or not.
-    virtual DrawType calculateDrawTypeInsideSelection () const;
+    virtual DrawType calculateDrawTypeInsideSelection() const;
 
     // Called by beginDraw() to determine what type of draw type is
     // being started.  The returned draw type is passed to operation().
@@ -287,29 +262,26 @@ protected:
     // supports "SelectText").  It also allows you to make certain
     // drags (e.g. dragging in the middle of a selection) do nothing by
     // returning "None" instead of calling the base implementation.
-    virtual DrawType calculateDrawType () const;
-public:
-    void beginDraw () override;
-
-
-//
-// Drawing - Mouse Movement
-//
+    virtual DrawType calculateDrawType() const;
 
 public:
-    void hover (const QPoint &point) override;
-    void draw (const QPoint &thisPoint, const QPoint &lastPoint,
-                       const QRect &normalizedRect) override;
+    void beginDraw() override;
 
-
-//
-// Drawing - Ending a Drag
-//
+    //
+    // Drawing - Mouse Movement
+    //
 
 public:
-    void cancelShape () override;
-    void releasedAllButtons () override;
+    void hover(const QPoint &point) override;
+    void draw(const QPoint &thisPoint, const QPoint &lastPoint, const QRect &normalizedRect) override;
 
+    //
+    // Drawing - Ending a Drag
+    //
+
+public:
+    void cancelShape() override;
+    void releasedAllButtons() override;
 
 protected:
     // Displays the right-mouse-button-triggered selection menu, re-entering
@@ -321,18 +293,17 @@ protected:
     //          If you are calling this from a view/tool event handler,
     //          either make all your handlers re-entrant or do not put any
     //          code in your handler after the call.
-    void popupRMBMenu ();
+    void popupRMBMenu();
+
 public:
-    void endDraw (const QPoint &thisPoint, const QRect &normalizedRect) override;
+    void endDraw(const QPoint &thisPoint, const QRect &normalizedRect) override;
 
-
-//
-// Drawing - Operation Dispatching
-//
+    //
+    // Drawing - Operation Dispatching
+    //
 
 protected:
-    enum Operation
-    {
+    enum Operation {
         //
         // These may be called outside of a drawing operation where
         // drawType() will return None.
@@ -343,40 +314,38 @@ protected:
 
         SetCursor,
 
-
         //
         // Called to start, to end, or inside, a drawing operation.
         //
 
-        BeginDraw, Draw, Cancel, EndDraw
+        BeginDraw,
+        Draw,
+        Cancel,
+        EndDraw
     };
 
     // (See the class API Doc for a description).
-    virtual QVariant operation (DrawType drawType, Operation op,
-        const QVariant &data1 = QVariant (), const QVariant &data2 = QVariant ());
+    virtual QVariant operation(DrawType drawType, Operation op, const QVariant &data1 = QVariant(), const QVariant &data2 = QVariant());
 
-
-//
-// Create
-//
+    //
+    // Create
+    //
 
 private:
     // Called by constructor to initialize the "Create" draw type.
-    void initCreate ();
+    void initCreate();
     // Called by destructor to uninitialize the "Create" draw type.
-    void uninitCreate ();
-
+    void uninitCreate();
 
 private:
-    void beginCreate ();
-    void endCreate ();
-
+    void beginCreate();
+    void endCreate();
 
 protected:
-    virtual QString haventBegunDrawUserMessageCreate () const = 0;
-private:
-    void setCursorCreate ();
+    virtual QString haventBegunDrawUserMessageCreate() const = 0;
 
+private:
+    void setCursorCreate();
 
 protected:
     // Sets the selection border mode when beginning to drag to create a
@@ -385,10 +354,10 @@ protected:
     // Subclasses may wish to reimplement but should still call the base
     // implementation.  Reimplementations should wrap the whole
     // reimplementation in a kpViewManager::setQueueUpdates() block.
-    virtual void setSelectionBorderForBeginDrawCreate ();
-private:
-    void beginDrawCreate ();
+    virtual void setSelectionBorderForBeginDrawCreate();
 
+private:
+    void beginDrawCreate();
 
 protected:
     //
@@ -424,46 +393,37 @@ protected:
     //   2. <normalizedRect>:
     //      This is as passed to kpTool::draw().
     //
-    virtual bool drawCreateMoreSelectionAndUpdateStatusBar (
-        bool dragAccepted,
-        const QPoint &accidentalDragAdjustedPoint,
-        const QRect &normalizedRect) = 0;
-    void drawCreate (const QPoint &thisPoint, const QRect &normalizedRect);
+    virtual bool drawCreateMoreSelectionAndUpdateStatusBar(bool dragAccepted, const QPoint &accidentalDragAdjustedPoint, const QRect &normalizedRect) = 0;
+    void drawCreate(const QPoint &thisPoint, const QRect &normalizedRect);
 private Q_SLOTS:
-    void delayedDrawCreate ();
-
+    void delayedDrawCreate();
 
 private:
-    void cancelCreate ();
-    void endDrawCreate ();
-
+    void cancelCreate();
+    void endDrawCreate();
 
 private:
-    QVariant operationCreate (Operation op,
-        const QVariant &data1, const QVariant &data2);
+    QVariant operationCreate(Operation op, const QVariant &data1, const QVariant &data2);
 
-
-//
-// Move
-//
+    //
+    // Move
+    //
 
 private:
     // Called by constructor to initialize the "Move" draw type.
-    void initMove ();
+    void initMove();
     // Called by destructor to uninitialize the "Move" draw type.
-    void uninitMove ();
-
+    void uninitMove();
 
 private:
-    void beginMove ();
-    void endMove ();
-
+    void beginMove();
+    void endMove();
 
 protected:
-    virtual QString haventBegunDrawUserMessageMove () const = 0;
-private:
-    void setCursorMove ();
+    virtual QString haventBegunDrawUserMessageMove() const = 0;
 
+private:
+    void setCursorMove();
 
 protected:
     // Sets the selection border mode when beginning to drag to move a
@@ -472,57 +432,52 @@ protected:
     // Subclasses may wish to reimplement but should still call the base
     // implementation.  Reimplementations should wrap the whole
     // reimplementation in a kpViewManager::setQueueUpdates() block.
-    virtual void setSelectionBorderForBeginDrawMove ();
+    virtual void setSelectionBorderForBeginDrawMove();
+
 private:
-    void beginDrawMove ();
+    void beginDrawMove();
 private Q_SLOTS:
-    void slotRMBMoveUpdateGUI ();
-
+    void slotRMBMoveUpdateGUI();
 
 private:
-    void drawMove (const QPoint &thisPoint, const QRect &normalizedRect);
-
+    void drawMove(const QPoint &thisPoint, const QRect &normalizedRect);
 
 private:
-    void cancelMove ();
+    void cancelMove();
+
 protected:
     // Returns what the name of the command that moves -- but does not smear
     // (not holding SHIFT) -- the selection, should be.
-    virtual QString nonSmearMoveCommandName () const;
-private:
-    void endDrawMove ();
-
+    virtual QString nonSmearMoveCommandName() const;
 
 private:
-    QVariant operationMove (Operation op,
-        const QVariant &data1, const QVariant &data2);
-
-
-//
-// Resize/Scale
-//
+    void endDrawMove();
 
 private:
-    int onSelectionResizeHandle () const;
+    QVariant operationMove(Operation op, const QVariant &data1, const QVariant &data2);
 
+    //
+    // Resize/Scale
+    //
+
+private:
+    int onSelectionResizeHandle() const;
 
 private:
     // Called by constructor to initialize the "Resize/Scale" draw type.
-    void initResizeScale ();
+    void initResizeScale();
     // Called by destructor to uninitialize the "Resize/Scale" draw type.
-    void uninitResizeScale ();
-
+    void uninitResizeScale();
 
 private:
-    void beginResizeScale ();
-    void endResizeScale ();
-
+    void beginResizeScale();
+    void endResizeScale();
 
 protected:
-    virtual QString haventBegunDrawUserMessageResizeScale () const = 0;
-private:
-    void setCursorResizeScale ();
+    virtual QString haventBegunDrawUserMessageResizeScale() const = 0;
 
+private:
+    void setCursorResizeScale();
 
 protected:
     // Sets the selection border mode when beginning to drag to resize or
@@ -531,10 +486,10 @@ protected:
     // Subclasses may wish to reimplement but should still call the base
     // implementation.  Reimplementations should wrap the whole
     // reimplementation in a kpViewManager::setQueueUpdates() block.
-    virtual void setSelectionBorderForBeginDrawResizeScale ();
-private:
-    void beginDrawResizeScale ();
+    virtual void setSelectionBorderForBeginDrawResizeScale();
 
+private:
+    void beginDrawResizeScale();
 
 private:
     // drawResizeScaleCalculateNewSelectionPosSize() calls us with what the
@@ -551,50 +506,43 @@ private:
     // The method should output its attempt at maintaining the aspect ratio.
     // We say "attempt" because it is constrained by the minimum allowed
     // size of the selection.
-    void drawResizeScaleTryKeepAspect (int newWidth, int newHeight,
-        bool horizontalGripDragged, bool verticalGripDragged,
-        const kpAbstractSelection &originalSelection,
-        int *newWidthOut, int *newHeightOut);
+    void drawResizeScaleTryKeepAspect(int newWidth,
+                                      int newHeight,
+                                      bool horizontalGripDragged,
+                                      bool verticalGripDragged,
+                                      const kpAbstractSelection &originalSelection,
+                                      int *newWidthOut,
+                                      int *newHeightOut);
 
-    void drawResizeScaleCalculateNewSelectionPosSize (
-        const kpAbstractSelection &originalSelection,
-        int *newX, int *newY,
-        int *newWidth, int *newHeight);
-
-    void drawResizeScale (const QPoint &thisPoint, const QRect &normalizedRect);
+    void drawResizeScaleCalculateNewSelectionPosSize(const kpAbstractSelection &originalSelection, int *newX, int *newY, int *newWidth, int *newHeight);
 
+    void drawResizeScale(const QPoint &thisPoint, const QRect &normalizedRect);
 
 private:
-    void cancelResizeScale ();
-    void endDrawResizeScale ();
-
+    void cancelResizeScale();
+    void endDrawResizeScale();
 
 private:
-    QVariant operationResizeScale (Operation op,
-        const QVariant &data1, const QVariant &data2);
+    QVariant operationResizeScale(Operation op, const QVariant &data1, const QVariant &data2);
 
-
-//
-// User Setting Selection Options
-//
+    //
+    // User Setting Selection Options
+    //
 
 protected Q_SLOTS:
-    virtual void slotIsOpaqueChanged (bool isOpaque) = 0;
+    virtual void slotIsOpaqueChanged(bool isOpaque) = 0;
 
-
-//
-// Keyboard Events
-//
+    //
+    // Keyboard Events
+    //
 
 protected:
     // Reimplemented to trap Esc presses for deselecting the selection.
     // All other keypresses are passed to the base implementation.
-    void keyPressEvent (QKeyEvent *e) override;
-
+    void keyPressEvent(QKeyEvent *e) override;
 
 private:
-    struct kpAbstractSelectionToolPrivate * const d;
+    struct kpAbstractSelectionToolPrivate *const d;
 };
 
-
-#endif  // kpAbstractSelectionTool_H
+#endif // kpAbstractSelectionTool_H
